Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearToken(
) → Future< void> -
getCustomer(
String accessToken) → Future< Customer> -
getSavedToken(
) → Future< CustomerAccessToken?> -
login(
{required String email, required String password}) → Future< CustomerAccessToken> -
logout(
String accessToken) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recoverPassword(
String email) → Future< void> -
register(
{required String email, required String password, required String firstName, required String lastName, String? phone, bool acceptsMarketing = false}) → Future< Customer> -
renewToken(
String accessToken) → Future< CustomerAccessToken> -
saveToken(
CustomerAccessToken token) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited