CachePolicy enum

Controls how the two-tier cache (memory + disk) is consulted.

Inheritance
Available extensions

Values

networkOnly → const CachePolicy

Always fetch from network; never read from cache.

cacheFirst → const CachePolicy

Read from cache first; fetch from network only on miss.

networkFirst → const CachePolicy

Fetch from network first; fall back to cache on failure.

cacheAndNetwork → const CachePolicy

Return cached data immediately AND fetch from network in background to update the cache (stale-while-revalidate).

cacheOnly → const CachePolicy

Read from cache only; throw on miss.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CachePolicy>
A constant List of the values in this enum, in order of their declaration.