CartDiscountCode class final

An applied discount code on a cart.

Constructors

CartDiscountCode({required String code, required bool applicable})
const
CartDiscountCode.fromJson(Map<String, dynamic> json)
factory

Properties

applicable bool
final
code String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited