CollectionRepository class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCollectionByHandle(String handle, {int productsFirst = 20, String? productsAfter, CollectionProductSortKey sortKey, bool reverse, String? country, String? language}) Future<Collection>
getCollectionById(String id, {String? country, String? language}) Future<Collection>
getCollections({int first = 20, String? after, String? country, String? language}) Future<ShopifyPage<Collection>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited