GraphQLRequestBuilder class final

Fluent builder for constructing GraphQLRequest instances.

final request = GraphQLRequestBuilder()
  .query(ProductQueries.getProduct)
  .variable('id', 'gid://shopify/Product/123')
  .variable('country', 'US')
  .build();

Constructors

GraphQLRequestBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() GraphQLRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
operationName(String name) GraphQLRequestBuilder
query(String query) GraphQLRequestBuilder
toString() String
A string representation of this object.
inherited
variable(String key, dynamic value) GraphQLRequestBuilder
variables(Map<String, dynamic> vars) GraphQLRequestBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited