PredictiveSearchResult class final

A single predictive search suggestion (product, collection, or query).

Constructors

PredictiveSearchResult({List<Product> products = const [], List<Collection> collections = const [], List<String> queries = const []})
const
PredictiveSearchResult.fromJson(Map<String, dynamic> json)
factory

Properties

collections List<Collection>
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
products List<Product>
final
queries List<String>
Suggested search queries (auto-complete strings).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited