QueryCost class final

Shopify Storefront API query cost (useful for rate-limit budgeting).

Constructors

QueryCost({required int requestedQueryCost, required int actualQueryCost, required ThrottleStatus throttleStatus})
const
QueryCost.fromJson(Map<String, dynamic> json)
factory

Properties

actualQueryCost int
final
hashCode int
The hash code for this object.
no setterinherited
requestedQueryCost int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throttleStatus ThrottleStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited