GraphQLResponse<T> class
final
Typed result returned by the GraphQL engine for every query and mutation.
Constructors
-
GraphQLResponse.failure(List<
GraphQLError> errors) -
factory
-
GraphQLResponse.fromJson(Map<
String, dynamic> json, T fromData(Map<String, dynamic> )) -
factory
-
GraphQLResponse.success(T data, [Map<
String, dynamic> ? extensions]) -
factory
Properties
- data → T?
-
final
- dataOrThrow → T
-
Throws ShopifyGraphQLException if the response contains errors.
no setter
-
errors
→ List<
GraphQLError> ? -
final
-
extensions
→ Map<
String, dynamic> ? -
final
- hasData → bool
-
no setter
- hasErrors → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- queryCost → QueryCost?
-
Cost info from the Shopify query cost extension.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited